Changed some forgotten references to Qt5 to Qt6. eric7

Sat, 28 Aug 2021 19:57:35 +0200

author
Detlev Offenbach <detlev@die-offenbachs.de>
date
Sat, 28 Aug 2021 19:57:35 +0200
branch
eric7
changeset 8549
15eca21fd968
parent 8548
c87eb20797b7
child 8550
575e640836b2

Changed some forgotten references to Qt5 to Qt6.

eric7/DebugClients/Python/DebugClientBase.py file | annotate | diff | comparison | revisions
eric7/Documentation/Help/source.qch file | annotate | diff | comparison | revisions
eric7/Documentation/Source/eric7.DebugClients.Python.DebugClientBase.html file | annotate | diff | comparison | revisions
eric7/Documentation/Source/eric7.Plugins.WizardPlugins.FileDialogWizard.FileDialogWizardDialog.html file | annotate | diff | comparison | revisions
eric7/Documentation/Source/eric7.Plugins.WizardPlugins.InputDialogWizard.InputDialogWizardDialog.html file | annotate | diff | comparison | revisions
eric7/Documentation/Source/eric7.Preferences.__init__.html file | annotate | diff | comparison | revisions
eric7/Documentation/Source/eric7.WebBrowser.QtHelp.HelpDocsInstaller.html file | annotate | diff | comparison | revisions
eric7/Globals/__init__.py file | annotate | diff | comparison | revisions
eric7/Plugins/WizardPlugins/FileDialogWizard/FileDialogWizardDialog.py file | annotate | diff | comparison | revisions
eric7/Plugins/WizardPlugins/InputDialogWizard/InputDialogWizardDialog.py file | annotate | diff | comparison | revisions
eric7/Preferences/ConfigurationPages/QtPage.py file | annotate | diff | comparison | revisions
eric7/Preferences/__init__.py file | annotate | diff | comparison | revisions
eric7/WebBrowser/QtHelp/HelpDocsInstaller.py file | annotate | diff | comparison | revisions
--- a/eric7/DebugClients/Python/DebugClientBase.py	Sat Aug 28 19:48:56 2021 +0200
+++ b/eric7/DebugClients/Python/DebugClientBase.py	Sat Aug 28 19:57:35 2021 +0200
@@ -1629,7 +1629,7 @@
         
     def __formatQtVariable(self, value, qttype):
         """
-        Private method to produce a formatted output of a simple Qt5 type.
+        Private method to produce a formatted output of a simple Qt5/Qt6 type.
         
         @param value variable to be formatted
         @param qttype type of the Qt variable to be formatted (string)
Binary file eric7/Documentation/Help/source.qch has changed
--- a/eric7/Documentation/Source/eric7.DebugClients.Python.DebugClientBase.html	Sat Aug 28 19:48:56 2021 +0200
+++ b/eric7/Documentation/Source/eric7.DebugClients.Python.DebugClientBase.html	Sat Aug 28 19:57:35 2021 +0200
@@ -136,7 +136,7 @@
 </tr>
 <tr>
 <td><a href="#DebugClientBase.__formatQtVariable">__formatQtVariable</a></td>
-<td>Private method to produce a formatted output of a simple Qt5 type.</td>
+<td>Private method to produce a formatted output of a simple Qt5/Qt6 type.</td>
 </tr>
 <tr>
 <td><a href="#DebugClientBase.__formatVariablesList">__formatVariablesList</a></td>
@@ -495,7 +495,7 @@
 <b>__formatQtVariable</b>(<i>value, qttype</i>)
 
 <p>
-        Private method to produce a formatted output of a simple Qt5 type.
+        Private method to produce a formatted output of a simple Qt5/Qt6 type.
 </p>
 <dl>
 
--- a/eric7/Documentation/Source/eric7.Plugins.WizardPlugins.FileDialogWizard.FileDialogWizardDialog.html	Sat Aug 28 19:48:56 2021 +0200
+++ b/eric7/Documentation/Source/eric7.Plugins.WizardPlugins.FileDialogWizard.FileDialogWizardDialog.html	Sat Aug 28 19:57:35 2021 +0200
@@ -98,7 +98,7 @@
 </tr>
 <tr>
 <td><a href="#FileDialogWizardDialog.getCode">getCode</a></td>
-<td>Public method to get the source code for Qt5.</td>
+<td>Public method to get the source code for Qt6.</td>
 </tr>
 <tr>
 <td><a href="#FileDialogWizardDialog.on_bTest_clicked">on_bTest_clicked</a></td>
@@ -211,7 +211,7 @@
 <b>getCode</b>(<i>indLevel, indString</i>)
 
 <p>
-        Public method to get the source code for Qt5.
+        Public method to get the source code for Qt6.
 </p>
 <dl>
 
--- a/eric7/Documentation/Source/eric7.Plugins.WizardPlugins.InputDialogWizard.InputDialogWizardDialog.html	Sat Aug 28 19:48:56 2021 +0200
+++ b/eric7/Documentation/Source/eric7.Plugins.WizardPlugins.InputDialogWizard.InputDialogWizardDialog.html	Sat Aug 28 19:57:35 2021 +0200
@@ -78,7 +78,7 @@
 </tr>
 <tr>
 <td><a href="#InputDialogWizardDialog.getCode">getCode</a></td>
-<td>Public method to get the source code for Qt5.</td>
+<td>Public method to get the source code for Qt6.</td>
 </tr>
 <tr>
 <td><a href="#InputDialogWizardDialog.on_bTest_clicked">on_bTest_clicked</a></td>
@@ -118,7 +118,7 @@
 <b>getCode</b>(<i>indLevel, indString</i>)
 
 <p>
-        Public method to get the source code for Qt5.
+        Public method to get the source code for Qt6.
 </p>
 <dl>
 
--- a/eric7/Documentation/Source/eric7.Preferences.__init__.html	Sat Aug 28 19:48:56 2021 +0200
+++ b/eric7/Documentation/Source/eric7.Preferences.__init__.html	Sat Aug 28 19:57:35 2021 +0200
@@ -199,11 +199,11 @@
 </tr>
 <tr>
 <td><a href="#getQtDocDir">getQtDocDir</a></td>
-<td>Module function to retrieve the Qt5DocDir setting.</td>
+<td>Module function to retrieve the Qt5DocDir/Qt6DocDir setting.</td>
 </tr>
 <tr>
 <td><a href="#getQtTranslationsDir">getQtTranslationsDir</a></td>
-<td>Module function to retrieve the Qt5TranslationsDir setting depending on the current Qt version.</td>
+<td>Module function to retrieve the Qt6TranslationsDir setting depending on the current Qt version.</td>
 </tr>
 <tr>
 <td><a href="#getShell">getShell</a></td>
@@ -1529,7 +1529,7 @@
 <b>getQtDocDir</b>(<i>version, prefClass=Prefs</i>)
 
 <p>
-    Module function to retrieve the Qt5DocDir setting.
+    Module function to retrieve the Qt5DocDir/Qt6DocDir setting.
 </p>
 <dl>
 
@@ -1545,7 +1545,7 @@
 <dl>
 <dt>Return:</dt>
 <dd>
-the requested Qt5DocDir setting
+the requested Qt5DocDir/Qt6DocDir setting
 </dd>
 </dl>
 <dl>
@@ -1562,7 +1562,7 @@
 <b>getQtTranslationsDir</b>(<i>prefClass=Prefs</i>)
 
 <p>
-    Module function to retrieve the Qt5TranslationsDir
+    Module function to retrieve the Qt6TranslationsDir
     setting depending on the current Qt version.
 </p>
 <dl>
--- a/eric7/Documentation/Source/eric7.WebBrowser.QtHelp.HelpDocsInstaller.html	Sat Aug 28 19:48:56 2021 +0200
+++ b/eric7/Documentation/Source/eric7.WebBrowser.QtHelp.HelpDocsInstaller.html	Sat Aug 28 19:57:35 2021 +0200
@@ -163,7 +163,7 @@
 </dd>
 <dt><i>version</i></dt>
 <dd>
-Qt version of the help documens (integer)
+Qt version of the help documents (integer)
 </dd>
 <dt><i>engine</i></dt>
 <dd>
--- a/eric7/Globals/__init__.py	Sat Aug 28 19:48:56 2021 +0200
+++ b/eric7/Globals/__init__.py	Sat Aug 28 19:57:35 2021 +0200
@@ -325,7 +325,7 @@
             import qt6_applications
             path = os.path.join(os.path.dirname(qt6_applications.__file__),
                                 "Qt", "bin")
-            # if qt5-applications is not installed just go to the next step
+            # if qt6-applications is not installed just go to the next step
     
     # step 3: determine from used Python interpreter (designer is test object)
     if not path:
--- a/eric7/Plugins/WizardPlugins/FileDialogWizard/FileDialogWizardDialog.py	Sat Aug 28 19:48:56 2021 +0200
+++ b/eric7/Plugins/WizardPlugins/FileDialogWizard/FileDialogWizardDialog.py	Sat Aug 28 19:57:35 2021 +0200
@@ -270,21 +270,12 @@
             else:
                 options |= QFileDialog.Option(0)
             options = self.__adjustOptions(options)
-            try:
-                QFileDialog.getExistingDirectoryUrl(
-                    None,
-                    self.eCaption.text(),
-                    QUrl(self.eWorkDir.text()),
-                    options,
-                    self.schemesEdit.text().split())
-            except TypeError:
-                # PyQt5 < 5.13.0 contains an error
-                QFileDialog.getExistingDirectoryUrl(
-                    None,
-                    self.eCaption.text(),
-                    self.eWorkDir.text(),
-                    options,
-                    self.schemesEdit.text().split())
+            QFileDialog.getExistingDirectoryUrl(
+                None,
+                self.eCaption.text(),
+                QUrl(self.eWorkDir.text()),
+                options,
+                self.schemesEdit.text().split())
     
     def __toggleConfirmCheckBox(self):
         """
@@ -332,7 +323,7 @@
     
     def getCode(self, indLevel, indString):
         """
-        Public method to get the source code for Qt5.
+        Public method to get the source code for Qt6.
         
         @param indLevel indentation level (int)
         @param indString string used for indentation (space or tab) (string)
--- a/eric7/Plugins/WizardPlugins/InputDialogWizard/InputDialogWizardDialog.py	Sat Aug 28 19:48:56 2021 +0200
+++ b/eric7/Plugins/WizardPlugins/InputDialogWizard/InputDialogWizardDialog.py	Sat Aug 28 19:57:35 2021 +0200
@@ -115,7 +115,7 @@
         
     def getCode(self, indLevel, indString):
         """
-        Public method to get the source code for Qt5.
+        Public method to get the source code for Qt6.
         
         @param indLevel indentation level (int)
         @param indString string used for indentation (space or tab) (string)
--- a/eric7/Preferences/ConfigurationPages/QtPage.py	Sat Aug 28 19:48:56 2021 +0200
+++ b/eric7/Preferences/ConfigurationPages/QtPage.py	Sat Aug 28 19:57:35 2021 +0200
@@ -57,7 +57,7 @@
         
         # set initial values
         self.qtTransPicker.setText(
-            Preferences.getQt("Qt5TranslationsDir"))
+            Preferences.getQt("Qt6TranslationsDir"))
         
         # Qt
         self.qtToolsDirPicker.setText(Preferences.getQt("QtToolsDir"))
@@ -95,7 +95,7 @@
         """
         Public slot to save the Qt configuration.
         """
-        Preferences.setQt("Qt5TranslationsDir", self.qtTransPicker.text())
+        Preferences.setQt("Qt6TranslationsDir", self.qtTransPicker.text())
         Preferences.setQt("QtToolsDir", self.qtToolsDirPicker.text())
         Preferences.setQt("QtToolsPrefix", self.qtPrefixEdit.text())
         Preferences.setQt("QtToolsPostfix", self.qtPostfixEdit.text())
--- a/eric7/WebBrowser/QtHelp/HelpDocsInstaller.py	Sat Aug 28 19:48:56 2021 +0200
+++ b/eric7/WebBrowser/QtHelp/HelpDocsInstaller.py	Sat Aug 28 19:57:35 2021 +0200
@@ -110,7 +110,7 @@
         Private method to install/update a Qt help document.
         
         @param name name of the Qt help document (string)
-        @param version Qt version of the help documens (integer)
+        @param version Qt version of the help documents (integer)
         @param engine reference to the help engine (QHelpEngineCore)
         @return flag indicating success (boolean)
         """

eric ide

mercurial
--- a/eric7/Preferences/__init__.py	Sat Aug 28 19:48:56 2021 +0200
+++ b/eric7/Preferences/__init__.py	Sat Aug 28 19:57:35 2021 +0200
@@ -1183,7 +1183,7 @@
 
     # defaults for Qt related stuff
     qtDefaults = {
-        "Qt5TranslationsDir": "",
+        "Qt6TranslationsDir": "",
         "QtToolsDir": "",
         "QtToolsPrefix": "",
         "QtToolsPostfix": "",
@@ -2170,7 +2170,7 @@
         else:
             return QColor(col)
     else:
         # palette based defaults here because of Qt5
         if key == "EditAreaForeground":
             return QApplication.palette().color(QPalette.ColorGroup.Active,
                                                 QPalette.ColorRole.Base)
@@ -2653,12 +2653,12 @@
 
 def getQtDocDir(version, prefClass=Prefs):
     """
     Module function to retrieve the Qt5DocDir setting.
     
     @param version Qt version to get documentation directory for
     @type int
     @param prefClass preferences class used as the storage area
-    @return the requested Qt5DocDir setting
+    @return the requested Qt5DocDir/Qt6DocDir setting
     @rtype str
     """
     key = "Qt{0}DocDir".format(version)
@@ -2938,15 +2938,15 @@
 
 def getQtTranslationsDir(prefClass=Prefs):
     """
     Module function to retrieve the Qt5TranslationsDir
     setting depending on the current Qt version.
     
     @param prefClass preferences class used as the storage area
     @return the requested setting (string)
     """
     s = prefClass.settings.value(
-        "Qt/Qt5TranslationsDir",
-        prefClass.qtDefaults["Qt5TranslationsDir"])
+        "Qt/Qt6TranslationsDir",
+        prefClass.qtDefaults["Qt6TranslationsDir"])
     if s == "":
         s = QLibraryInfo.path(
             QLibraryInfo.LibraryPath.TranslationsPath)
@@ -2966,7 +2966,7 @@
     @param prefClass preferences class used as the storage area
     @return the requested Qt setting
     """
-    if key in ["Qt5TranslationsDir"]:
+    if key in ["Qt6TranslationsDir"]:
         return getQtTranslationsDir(prefClass)
     elif key in ["PyuicIndent", "Pyuic6Indent"]:
         return int(prefClass.settings.value(
@@ -2170,7 +2170,7 @@
             return QColor(col)
     else:
-        # palette based defaults here because of Qt5
+        # palette based defaults here because of Qt6
         if key == "EditAreaForeground":
             return QApplication.palette().color(QPalette.ColorGroup.Active,
@@ -2653,12 +2653,12 @@
 def getQtDocDir(version, prefClass=Prefs):
     """
-    Module function to retrieve the Qt5DocDir setting.
+    Module function to retrieve the Qt5DocDir/Qt6DocDir setting.
     
     @param version Qt version to get documentation directory for
@@ -2938,15 +2938,15 @@
 def getQtTranslationsDir(prefClass=Prefs):
     """
-    Module function to retrieve the Qt5TranslationsDir
+    Module function to retrieve the Qt6TranslationsDir
     setting depending on the current Qt version.
     